from _typeshed import Incomplete
from common_utils.logger import create_logger as create_logger

class FirebaseClient:
    log: Incomplete
    headers: Incomplete
    database_url: Incomplete
    def __init__(self, realtime_db_url: str | None = None, env_name: str = 'FIREBASE_REALTIME_DB_URL') -> None: ...
    def get_list(self, ref: str, max_results: int = 100, convert_to_list: bool = True): ...
    def get(self, ref: str): ...
    def set(self, ref: str, data: dict): ...
    def delete(self, ref: str): ...
    def get_entry(self, *args, **kwargs): ...
    def set_entry(self, *args, **kwargs): ...
    def delete_entry(self, *args, **kwargs): ...
    def update(self, ref: str, data: dict): ...
