import pandas as pd
from _typeshed import Incomplete
from common_utils.config import load_config_yaml as load_config_yaml, secret as secret
from common_utils.logger import create_logger as create_logger

class NotionClient:
    log: Incomplete
    api: Incomplete
    def __init__(self, notion_secret: Incomplete | None = None) -> None: ...
    def get_properties(self, page, property_mapping) -> dict: ...
    def get_database(self, database_id: str, properties_mapping: dict[str, str], filter={}, sort={}) -> pd.DataFrame: ...
    def get_multiple_databases(self, db_config_dict: dict[dict]) -> dict[str, pd.DataFrame]: ...
    def get_page_content(self, page_id: str, parse_mode: str) -> str: ...
    def add_property(self, prop_type, value): ...
    def create_db_entry(self, database_id, properties: Incomplete | None = None, data: Incomplete | None = None, properties_mapping: Incomplete | None = None) -> None: ...
