from _typeshed import Incomplete
from common_utils.logger import create_logger as create_logger
from datetime import datetime as datetime

def close_window_by_process(process_name): ...
def is_program_running(program_name): ...
def start_program(program_path) -> None: ...

class WindowHandler:
    log: Incomplete
    ignore_windows: Incomplete
    minimized_windows: Incomplete
    def __init__(self, ignore_windows: Incomplete | None = None) -> None: ...
    def get_user_windows(self): ...
    def minimize_open_windows(self) -> None: ...
    def restore_open_windows(self) -> None: ...
