from _typeshed import Incomplete
from common_utils.web.cookies_handler import CookiesManager as CookiesManager, LoginData as LoginData, LoginSelectors as LoginSelectors

url: str

class BudgetBakerHandler:
    cookies_manager: Incomplete
    cookies: Incomplete
    headers: Incomplete
    def __init__(self) -> None: ...
